@@ -55,6 +55,8 @@ class ProfileGroup;
  */
 class KONSOLEPRIVATE_EXPORT Profile : public QSharedData
 {
+    Q_GADGET
+
     friend class ProfileReader;
     friend class ProfileWriter;
     friend class ProfileGroup;
@@ -296,6 +298,8 @@ public:
         ReverseUrlHints
     };
 
+    Q_ENUM(Property)
+
     /**
      * Constructs a new profile
      *
