@@ -97,6 +97,7 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     , _session(session)
     , _view(view)
     , _copyToGroup(nullptr)
+    , _profileList(nullptr)
     , _sessionIcon(QIcon())
     , _sessionIconName(QString())
     , _previousState(-1)
@@ -222,18 +223,10 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     _bookmarkValidProgramsToClear << QStringLiteral("tcsh") << QStringLiteral("zsh");
     setupSearchBar();
     _searchBar->setVisible(_isSearchBarEnabled);
-
-    _profileList = ProfileManager::instance()->getProfileList();
-    connect(_profileList, &ProfileList::actionsChanged, this, &Konsole::SessionController::prepareSwitchProfileMenu);
-    prepareSwitchProfileMenu();
 }
 
 SessionController::~SessionController()
 {
-    if (!_view.isNull()) {
-        _view->setScreenWindow(nullptr);
-    }
-
     _allControllers.remove(this);
 
     if (!_editProfileDialog.isNull()) {
@@ -244,9 +237,27 @@ void SessionController::trackOutput(QKeyEvent* event)
 {
     Q_ASSERT(_view->screenWindow());
 
+    // Qt has broken something, so we can't rely on just checking if certain
+    // keys are passed as modifiers anymore.
+    const int key = event->key();
+    const bool shouldNotTriggerScroll =
+        key == Qt::Key_Super_L      ||
+        key == Qt::Key_Super_R      ||
+        key == Qt::Key_Hyper_L      ||
+        key == Qt::Key_Hyper_R      ||
+        key == Qt::Key_Shift        ||
+        key == Qt::Key_Control      ||
+        key == Qt::Key_Meta         ||
+        key == Qt::Key_Alt          ||
+        key == Qt::Key_AltGr        ||
+        key == Qt::Key_CapsLock     ||
+        key == Qt::Key_NumLock      ||
+        key == Qt::Key_ScrollLock;
+
+
     // Only jump to the bottom if the user actually typed something in,
     // not if the user e. g. just pressed a modifier.
-    if (event->text().isEmpty() && (event->modifiers() != 0u)) {
+    if (event->text().isEmpty() && (event->modifiers() || shouldNotTriggerScroll)) {
         return;
     }
 
@@ -459,7 +470,7 @@ void SessionController::configureWebShortcuts()
 
 void SessionController::sendSignal(QAction* action)
 {
-    const auto signal = action->data().value<int>();
+    const auto signal = action->data().toInt();
     _session->sendSignal(signal);
 }
 
@@ -493,9 +504,6 @@ bool SessionController::eventFilter(QObject* watched , QEvent* event)
         // second, connect the newly focused view to listen for the session's bell signal
         connect(_session.data(), &Konsole::Session::bellRequest, _view.data(), &Konsole::TerminalDisplay::bell);
 
-        disconnect(_profileList, &Konsole::ProfileList::profileSelected, nullptr, nullptr);
-        connect(_profileList, &Konsole::ProfileList::profileSelected, this, &Konsole::SessionController::switchProfile);
-
         if ((_copyInputToAllTabsAction != nullptr) && _copyInputToAllTabsAction->isChecked()) {
             // A session with "Copy To All Tabs" has come into focus:
             // Ensure that newly created sessions are included in _copyToGroup!
@@ -539,11 +547,7 @@ void SessionController::setupCommonActions()
 
     // Close Session
     QAction* action = collection->addAction(QStringLiteral("close-session"), this, SLOT(closeSession()));
-    if (isKonsolePart()) {
-        action->setText(i18n("&Close Session"));
-    } else {
-        action->setText(i18n("&Close Tab"));
-    }
+    action->setText(i18n("&Close Session"));
 
     action->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
     collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_W);
@@ -627,6 +631,7 @@ void SessionController::setupCommonActions()
 
     _switchProfileMenu = new KActionMenu(i18n("Switch Profile"), this);
     collection->addAction(QStringLiteral("switch-profile"), _switchProfileMenu);
+    connect(_switchProfileMenu->menu(), &QMenu::aboutToShow, this, &Konsole::SessionController::prepareSwitchProfileMenu);
 
     // History
     _findAction = KStandardAction::find(this, SLOT(searchBarEvent()), collection);
@@ -788,16 +793,17 @@ void SessionController::setupExtraActions()
 
 void SessionController::switchProfile(const Profile::Ptr &profile)
 {
-    if (isReadOnly()) {
-        return;
-    }
-
     SessionManager::instance()->setSessionProfile(_session, profile);
     updateFilterList(profile);
 }
 
 void SessionController::prepareSwitchProfileMenu()
 {
+    if (_switchProfileMenu->menu()->isEmpty()) {
+        _profileList = new ProfileList(false, this);
+        connect(_profileList, &Konsole::ProfileList::profileSelected, this, &Konsole::SessionController::switchProfile);
+    }
+
     _switchProfileMenu->menu()->clear();
     _switchProfileMenu->menu()->addActions(_profileList->actions());
 }
@@ -1016,7 +1022,7 @@ static bool hasTerminalDisplayInSameWindow(const Session* session, const KXmlGui
 
 void SessionController::copyInputActionsTriggered(QAction* action)
 {
-    const auto mode = action->data().value<int>();
+    const auto mode = action->data().toInt();
 
     switch (mode) {
     case CopyInputToAllTabsMode:
@@ -1682,15 +1688,6 @@ void SessionController::showDisplayContextMenu(const QPoint& position)
 
         // check for validity of the pointer to the popup menu
         if (!popup.isNull()) {
-            // Remove content-specific actions
-            //
-            // If the close action was chosen, the popup menu will be partially
-            // destroyed at this point, and the rest will be destroyed later by
-            // 'chosen->trigger()'
-            foreach(QAction * action, contentActions) {
-                popup->removeAction(action);
-            }
-
             delete contentSeparator;
         }
 
@@ -1766,7 +1763,6 @@ void SessionController::zmodemUpload()
                            i18n("<p>The current session already has a ZModem file transfer in progress.</p>"));
         return;
     }
-    _session->setZModemBusy(true);
 
     QString zmodem = QStandardPaths::findExecutable(QStringLiteral("sz"));
     if (zmodem.isEmpty()) {
