@@ -150,7 +150,9 @@ void ViewSplitter::handleFocusDirection(Qt::Orientation orientation, int directi
     auto parentSplitter = qobject_cast<ViewSplitter*>(terminalDisplay->parentWidget());
     auto topSplitter = parentSplitter->getToplevelSplitter();
 
-    const auto handleWidth = parentSplitter->handleWidth() <= 1 ? 4 : parentSplitter->handleWidth();
+    // Find the theme's splitter width + extra space to find valid terminal
+    // See https://bugs.kde.org/show_bug.cgi?id=411387 for more info
+    const auto handleWidth = parentSplitter->handleWidth() + 3;
 
     const auto start = QPoint(terminalDisplay->x(), terminalDisplay->y());
     const auto startMapped = parentSplitter->mapTo(topSplitter, start);
@@ -166,19 +168,21 @@ void ViewSplitter::handleFocusDirection(Qt::Orientation orientation, int directi
     const auto newPoint = QPoint(newX, newY);
     auto child = topSplitter->childAt(newPoint);
 
+    TerminalDisplay *focusTerminal = nullptr;
     if (TerminalDisplay* terminal = qobject_cast<TerminalDisplay*>(child)) {
-        terminal->setFocus(Qt::OtherFocusReason);
+        focusTerminal = terminal;
     } else if (qobject_cast<QSplitterHandle*>(child)) {
         auto targetSplitter = qobject_cast<QSplitter*>(child->parent());
-        auto splitterTerminal = qobject_cast<TerminalDisplay*>(targetSplitter->widget(0));
-        splitterTerminal->setFocus(Qt::OtherFocusReason);
+        focusTerminal = qobject_cast<TerminalDisplay*>(targetSplitter->widget(0));
     } else if (qobject_cast<QWidget*>(child)) {
         TerminalDisplay *terminalParent = nullptr;
-        while(!terminalParent) {
-            terminalParent = qobject_cast<TerminalDisplay*>(child->parentWidget());
+        while(child != nullptr && focusTerminal == nullptr) {
+            focusTerminal = qobject_cast<TerminalDisplay*>(child->parentWidget());
             child = child->parentWidget();
         }
-        terminalParent->setFocus(Qt::OtherFocusReason);
+    }
+    if (focusTerminal != nullptr) {
+        focusTerminal->setFocus(Qt::OtherFocusReason);
     }
 }
 
